@@ -1,7 +1,6 @@
 package OpenFrame::Slot::Exception;
 
 use strict;
-use warnings::register;
 use OpenFrame::Exception;
 
 
@@ -27,16 +26,16 @@ sub action {
     if ($module =~ /slot/i) {
       $module =~ s/\//\:\:/g;
       $module = substr($module, 0, rindex($module, '.'));
-      warnings::warn("$bgn caught $type: slot $module not found");
+      warn("$bgn caught $type: slot $module not found");
     } else {
-      warnings::warn("$bgn failed to load module: $module");
+      warn("$bgn failed to load module: $module");
     }
   } else {
-    warnings::warn("$bgn caught $type exception while handling request for $uri\n$excp->{message}");
+    warn("$bgn caught $type exception while handling request for $uri\n$excp->{message}");
   }
 
   $excp = $vars->lookup( 'OpenFrame::Exception::Slot' );
-  warnings::warn("$bgn $excp->{message}");
+  warn("$bgn $excp->{message}");
 
 }
 
